@@ -25,6 +25,7 @@ def helm_handler(event, context):
     chart        = props['Chart']
     version      = props.get('Version', None)
     wait         = props.get('Wait', False)
+    timeout      = props.get('Timeout', None)
     namespace    = props.get('Namespace', None)
     repository   = props.get('Repository', None)
     values_text  = props.get('Values', None)
@@ -45,14 +46,14 @@ def helm_handler(event, context):
             f.write(json.dumps(values, indent=2))
 
     if request_type == 'Create' or request_type == 'Update':
-        helm('upgrade', release, chart, repository, values_file, namespace, version)
+        helm('upgrade', release, chart, repository, values_file, namespace, version, wait, timeout)
     elif request_type == "Delete":
         try:
-            helm('uninstall', release, namespace=namespace)
+            helm('uninstall', release, namespace=namespace, timeout=timeout)
         except Exception as e:
             logger.info("delete error: %s" % e)
 
-def helm(verb, release, chart = None, repo = None, file = None, namespace = None, version = None, wait = False):
+def helm(verb, release, chart = None, repo = None, file = None, namespace = None, version = None, wait = False, timeout = None):
     import subprocess
 
     cmnd = ['helm', verb, release]
@@ -70,6 +71,8 @@ def helm(verb, release, chart = None, repo = None, file = None, namespace = None
         cmnd.extend(['--namespace', namespace])
     if wait:
         cmnd.append('--wait')
+    if not timeout is None:
+        cmnd.extend(['--timeout', timeout])  
     cmnd.extend(['--kubeconfig', kubeconfig])
 
     retry = 3
